pub fn radial(
center: Point,
radius: f64,
angle: f64,
style: DimensionStyle,
) -> GeoResult<DimensionGeometry>Expand description
Radial dimension from center to the circle at angle angle.
pub fn radial(
center: Point,
radius: f64,
angle: f64,
style: DimensionStyle,
) -> GeoResult<DimensionGeometry>Radial dimension from center to the circle at angle angle.