Vector

Struct Vector 

pub struct Vector {
    pub x: f64,
    pub y: f64,
}
A displacement in the plane. Serialized as [x, y].

Fields

x: f64

X component.

y: f64

Y component.

Implementations

Source

impl Vector

pub const ZERO: Self

Zero vector.

pub const fn new(x: f64, y: f64) -> Self

Create a vector.

pub fn from_angle(angle: f64) -> Self

Unit vector at angle radians from +X, counter-clockwise.

pub fn is_finite(self) -> bool

Both components are finite.

pub fn length(self) -> f64

Euclidean length (overflow-safe).

pub fn length_sq(self) -> f64

Squared length.

pub fn dot(self, o: Self) -> f64

Dot product.

pub fn cross(self, o: Self) -> f64

2D cross product (z component of the 3D cross product).

pub fn normalize(self) -> Option<Self>

Unit vector in the same direction, or None for a zero/non-finite vector.

pub const fn perp(self) -> Self

Rotate 90° counter-clockwise.

pub fn angle(self) -> f64

Angle from +X in radians, in (-π, π].

pub fn rotate(self, angle: f64) -> Self

Rotate by angle radians counter-clockwise.

pub const fn to_point(self) -> Point

Point at the tip of this vector from the origin.