TimeAxis

Struct TimeAxis 

pub struct TimeAxis {
    pub origin_s: f64,
    pub mm_per_second: f64,
}
Explicit mapping from a domain time axis to model X coordinates (timelines).

x_mm = (t_seconds - origin_s) * mm_per_second. The mapping is the only place where time becomes length; constraints work on time-dimensioned variables.

Fields

origin_s: f64

Domain time shown at x = 0.

mm_per_second: f64

Model millimetres per second.

Implementations

Source

impl TimeAxis

pub fn new(origin_s: f64, mm_per_second: f64) -> GeoResult<Self>

Create a validated axis.

pub fn to_x(self, t: Quantity) -> GeoResult<f64>

Model X for a time quantity.

pub fn time_at(self, x_mm: f64) -> Quantity

Time at model X.

pub fn width_of(self, duration: Quantity) -> GeoResult<f64>

Model width of a duration.