pub fn split_at(
shape: &Shape,
at: Point,
tol: ModelTolerance,
) -> GeoResult<Vec<Shape>>Expand description
Split a shape at the point on it closest to at.
Lines, arcs and open polylines yield two shapes; a closed polyline yields one open
polyline that starts and ends at the split point. Circles need two points: see
split_circle.